# Stellium Notables Index

This file is auto-generated by `generate_index.py`.

**Total entries:** 196

## Births

### Architect (3)

- **Frank Lloyd Wright** (1867) (architect)
- **I.M. Pei** (1917) (architect, Louvre Pyramid)
- **Zaha Hadid** (1950) (architect, first woman Pritzker Prize)

### Artist (14)

- **Alfred Stieglitz** (1864) (photographer, modern art promoter)
- **Andy Warhol** (1928) (painter, filmmaker, pop artist)
- **Claude Monet** (1840) (Painter, Impressionist)
- **Diego Rivera** (1886) (painter, muralist)
- **Frida Kahlo** (1907) (painter, surrealist)
- **Georgia O'Keeffe** (1887) (Painter, Modernist)
- **Henri Matisse** (1869) (Painter, Sculptor, Lithographer)
- **Leonardo da Vinci** (1452) (Painter, Sculptor, Engineer, Inventor, Scientist, Mathematician)
- **Michelangelo** (1475) (Sculptor, Painter, Architect, Poet)
- **Pablo Picasso** (1881) (painter, sculptor, cubist)
- **Pamela Colman Smith** (1878) (illustrator, commercial artist)
- **Salvador Dali** (1904) (Painter, Surrealist, Sculptor)
- **Vincent van Gogh** (1853) (Painter, Post-Impressionist)
- **Wassily Kandinsky** (1866) (Painter, Expressionist, Abstract Art Pioneer)

### Astrologer (6)

- **Alan Leo** (1860) (theosophist, author, publisher)
- **B.V. Raman** (1912) (Vedic astrologer, author)
- **Dane Rudhyar** (1895) (Humanistic Astrologer, Composer, Philosopher)
- **Evangeline Adams** (1868) (Astrologer)
- **K.N. Rao** (1931) (Vedic astrologer, author)
- **William Lilly** (1602) (Traditional Astrologer, Author, Horary Master)

### Athlete (10)

- **Billie Jean King** (1943) (tennis, equality advocate)
- **Bruce Lee** (1940) (Martial Artist, Actor, Philosopher)
- **Jackie Robinson** (1919) (baseball, broke color barrier)
- **Joe DiMaggio** (1914) (baseball player)
- **Michael Jordan** (1963) (Basketball Player, Businessman, Cultural Icon)
- **Muhammad Ali** (1942) (Boxer, Activist, Humanitarian)
- **Pelé** (1940) (Soccer Player)
- **Serena Williams** (1981) (Tennis Player, Entrepreneur, Activist)
- **Simone Biles** (1997) (gymnast)
- **Usain Bolt** (1986) (Track and Field)

### Business (7)

- **Aristotle Onassis** (1906) (entrepreneur, shipping magnate)
- **Bill Gates** (1955) (software developer, investor, philanthropist)
- **Elon Musk** (1971) (Entrepreneur, Engineer, Investor)
- **Steve Jobs** (1955) (Entrepreneur, Inventor, Visionary)
- **Steve Wozniak** (1950) (inventor, engineer)
- **Walt Disney** (1901) (Animator, Filmmaker, Theme Park Creator)
- **Warren Buffett** (1930) (Investor, Philanthropist)

### Criminal (3)

- **Al Capone** (1899) (Gangster)
- **Bonnie Parker** (1910) (murderer)
- **Ted Bundy** (1946) (Serial Killer)

### Explorer (5)

- **Amelia Earhart** (1897) (aviator)
- **Edmund Hillary** (1919) (Everest climber)
- **Jacques Cousteau** (1910) (oceanographer, explorer)
- **Neil Armstrong** (1930) (astronaut, first on Moon)
- **Yuri Gagarin** (1934) (first human in space)

### Leader (32)

- **Abraham Lincoln** (1809) (U.S. President, Lawyer, Public Speaker)
- **Angela Merkel** (1954) (German Chancellor)
- **Aung San Suu Kyi** (1945) (Myanmar, Nobel laureate)
- **Barack Obama** (1961) (U.S. President, Lawyer, Author)
- **Benazir Bhutto** (1953) (politician)
- **Catherine the Great** (1729) (Russian Empress)
- **Che Guevara** (1928) (revolutionary)
- **Dalai Lama XIV** (1935) (spiritual leader)
- **Eva Perón** (1919) (Argentine first lady, icon)
- **Fidel Castro** (1926) (revolutionary)
- **Gamal Abdel Nasser** (1918) (politician)
- **Golda Meir** (1898) (Israeli Prime Minister)
- **Hugo Chávez** (1954) (politician)
- **Indira Gandhi** (1917) (politician)
- **Jacqueline Kennedy Onassis** (1929) (first lady, editor)
- **John F. Kennedy** (1917) (U.S. President, author)
- **Kate Middleton** (1982) (Princess of Wales, Royal, Philanthropist)
- **Margaret Thatcher** (1925) (UK Prime Minister)
- **Martin Luther King Jr.** (1929) (civil_rights, minister, activist)
- **Michelle Obama** (1964) (First Lady, Lawyer, Author)
- **Mohandas Gandhi** (1869) (Political Activist, Lawyer)
- **Nelson Mandela** (1918) (Politician, Activist)
- **Patrice Lumumba** (1925) (politician)
- **Prince Philip** (1921) (royal family)
- **Prince William** (1982) (Prince of Wales, Royal, Philanthropist)
- **Princess of Wales Diana** (1961) (Princess, Royal, Humanitarian)
- **Queen Elizabeth II** (1926) (Queen, Head of State, Monarch)
- **Queen of the United Kingdom Victoria** (1819) (Queen, Empress, Monarch)
- **Rigoberta Menchú** (1959) (activist)
- **Thomas Sankara** (1949) (revolutionary)
- **Wangari Maathai** (1940) (activist, environmentalist)
- **Winston Churchill** (1874) (statesman, author)

### Media (38)

- **Aishwarya Rai** (1973) (actress)
- **Akira Kurosawa** (1910) (film director)
- **Alfred Hitchcock** (1899) (film director)
- **Angelina Jolie** (1975) (Actor, Filmmaker, Humanitarian)
- **Anita Mui** (1963) (singer, actress)
- **Audrey Hepburn** (1929) (actress, humanitarian)
- **Beyoncé** (1981) (Singer, Songwriter, Dancer)
- **Brad Pitt** (1963) (Actor, Producer, Film Star)
- **Charlie Chaplin** (1889) (actor, filmmaker, comedian)
- **Chow Yun-fat** (1955) (actor)
- **David Bowie** (1947) (musician, actor)
- **Dr. Dre** (1965) (rapper, producer)
- **Elizabeth Taylor** (1932) (Actress, Humanitarian, Film Star)
- **Eminem** (1972) (rapper, songwriter)
- **Faye Wong** (1969) (singer, actress)
- **Jay-Z** (1969) (rapper, record producer, entrepreneur)
- **John Lennon** (1940) (Singer, Songwriter, Peace Activist)
- **Kurt Cobain** (1967) (musician, singer)
- **Leslie Cheung** (1956) (singer, actor)
- **Lucille Ball** (1911) (comedian, TV pioneer)
- **Mariah Carey** (1969) (singer, songwriter)
- **Marilyn Monroe** (1926) (Actress, Model, Singer)
- **Miriam Makeba** (1932) (singer, activist)
- **Mozart** (1756) (Composer, Pianist, Child Prodigy)
- **Oprah Winfrey** (1954) (television, entrepreneur, philanthropist)
- **Paul McCartney** (1942) (Singer, Songwriter, Multi-instrumentalist)
- **Prince** (1958) (musician, singer)
- **Richard Burton** (1925) (Actor, Stage Actor, Film Star)
- **Robin Williams** (1951) (actor, comedian)
- **Ryuichi Sakamoto** (1952) (composer, musician)
- **Selena Quintanilla** (1971) (singer, Tejano musician)
- **Shah Rukh Khan** (1965) (actor)
- **Steven Spielberg** (1946) (film director)
- **Teresa Teng** (1953) (singer)
- **Tom Hanks** (1956) (Actor, Film Producer)
- **Wolfgang Mozart** (1756) (Composer, Pianist, Child Prodigy)
- **Wong Kar-wai** (1958) (filmmaker)
- **Yoko Ono** (1933) (Conceptual Artist, Musician, Peace Activist)

### Occultist (15)

- **Aleister Crowley** (1875) (Magician, Author, Poet)
- **Arthur Edward Waite** (1857) (mystic, author)
- **Chinmayananda Saraswati** (1916) (spiritual teacher)
- **Edgar Cayce** (1877) (Mystic, Psychic)
- **Helena Blavatsky** (1831) (Spiritualist, Mystic)
- **Jiddu Krishnamurti** (1895) (philosopher, speaker)
- **Nostradamus** (1503) (Astrologer, Physician, Seer)
- **Osho Rajneesh** (1931) (guru, mystic)
- **Paramahansa Yogananda** (1893) (yogi, guru)
- **Ramana Maharshi** (1879) (mystic, philosopher)
- **Sadhguru** (1957) (yogi, mystic)
- **Sri Aurobindo** (1872) (philosopher, yogi)
- **Sri Ramakrishna** (1836) (mystic, spiritual teacher)
- **Swami Vivekananda** (1863) (philosopher, monk)
- **Thich Nhat Hanh** (1926) (Zen master, peace activist)

### Philosopher (4)

- **Friedrich Nietzsche** (1844) (philosopher)
- **Hannah Arendt** (1906) (political theorist)
- **Jean-Paul Sartre** (1905) (existentialist)
- **Simone de Beauvoir** (1908) (existentialist, feminist)

### Scientist (20)

- **Ada Lovelace** (1815) (mathematician, computer pioneer)
- **Alan Turing** (1912) (mathematician, computer scientist, cryptanalyst)
- **Albert Einstein** (1879) (physicist, theorist)
- **Alexander Fleming** (1881) (penicillin discoverer)
- **Carl Sagan** (1934) (Astronomer, Astrophysicist, Author)
- **Charles Darwin** (1809) (Naturalist, Biologist)
- **Galileo Galilei** (1564) (Astronomer, Physicist, Mathematician)
- **Grace Hopper** (1906) (computer scientist, COBOL creator)
- **Isaac Newton** (1643) (Mathematician, Physicist, Astronomer, Astrologer)
- **Johannes Kepler** (1571) (Mathematician, Astronomer, Astrologer)
- **Marie Curie** (1867) (physicist, chemist)
- **Nicolaus Copernicus** (1473) (Astronomer, Mathematician, Author)
- **Nikola Tesla** (1856) (inventor, electrical_engineer)
- **Rachel Carson** (1907) (marine biologist, Silent Spring)
- **Richard Feynman** (1918) (physicist, Nobel laureate)
- **Rosalind Franklin** (1920) (crystallographer, DNA structure)
- **Sigmund Freud** (1856) (Psychologist, Neurologist, Author)
- **Stephen Hawking** (1942) (Physicist)
- **Thomas Edison** (1847) (Inventor, Businessman, Engineer)
- **Tim Berners-Lee** (1955) (invented the World Wide Web)

### Writer (18)

- **Agatha Christie** (1890) (mystery novelist)
- **Amrita Pritam** (1919) (poet, novelist)
- **Arthur Miller** (1915) (playwright, writer)
- **Carl Jung** (1875) (Psychiatrist, Author, Astrologer)
- **Ernest Hemingway** (1899) (novelist, journalist)
- **Franz Kafka** (1883) (novelist)
- **Fyodor Dostoevsky** (1821) (Novelist, Philosopher, Essayist)
- **Gabriel García Márquez** (1927) (magical realism, Nobel)
- **Jane Austen** (1775) (Novelist)
- **Jorge Luis Borges** (1899) (writer, poet)
- **Maya Angelou** (1928) (poet, author, activist)
- **Oscar Wilde** (1854) (playwright, wit)
- **Rumi** (1207) (Sufi poet)
- **Sylvia Plath** (1932) (poet, novelist)
- **Terry Pratchett** (1948) (novelist, humorist)
- **Toni Morrison** (1931) (novelist, Nobel laureate)
- **Virginia Woolf** (1882) (novelist, modernist)
- **William Shakespeare** (1564) (Playwright, Poet, Actor)

## Events

- **1929 Stock Market Crash** (1929)
- **Arab Spring begins Tunisia** (2010)
- **Atomic Bombing of Hiroshima** (1945)
- **COVID-19 WHO Declaration** (2020)
- **Challenger Disaster** (1986)
- **Chernobyl Explosion** (1986)
- **Death of Mao Zedong** (1976)
- **End of World War II** (1945)
- **Fall of the Berlin Wall** (1989)
- **Fukushima Daiichi meltdown** (2011)
- **Indian Independence** (1947)
- **John F. Kennedy Assassination** (1963)
- **Moon Landing** (1969)
- **Pearl Harbor Attack** (1941)
- **People’s Republic of China founding** (1949)
- **September 11 Attacks** (2001)
- **Sputnik Launch** (1957)
- **Tiananmen Square protests climax** (1989)
- **Titanic Sinking** (1912)
- **Trinity Nuclear Test** (1945)
- **Wright Brothers First Flight** (1903)
